boj_databases: List Bank of Japan API databases

View source: R/databases.R

boj_databasesR Documentation

List Bank of Japan API databases

Description

Returns the database identifiers accepted by db in the BOJ API. The registry follows the February 18, 2026 API manual. New databases may be accepted by the API before this package registry is updated.

Usage

boj_databases()

Value

A tibble with database code, English category, and English and Japanese database names.

Examples

boj_databases()
subset(boj_databases(), grepl("Exchange", name_en))

bojapi documentation built on July 24, 2026, 5:07 p.m.