| boj_databases | R Documentation |
Returns the database identifiers accepted by db in the BOJ API. The
registry follows the February 18, 2026 API manual. New databases may be
accepted by the API before this package registry is updated.
boj_databases()
A tibble with database code, English category, and English and Japanese database names.
boj_databases()
subset(boj_databases(), grepl("Exchange", name_en))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.